==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>所有字體</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統字體</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用戶字體</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>已啟動</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中文字體</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>等寬字體</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>文件已損壞</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>系統字體</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>字體</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>已安裝%1個字體</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>已安裝%1個字體</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>您確定要刪除該字體嗎？</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>刪除後該字體將不可用於其他應用程序</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>刪除後這些字體將不可用於其他應用程序</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>無法刪除其他%1個系統字體</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>無法刪除正在使用的字體：%1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>無法刪除其他%1個系統字體和正在使用的字體：%2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>您確定要刪除這%1個字體嗎？</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>正在刪除字體，請稍候...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>字體驗證</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>無可用安裝字體</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>因理想而出生，為責任而成長</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>樣式</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>全名</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS名稱</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>商標</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>字體管理器</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>字體管理器是一款幫助用戶安裝和管理字體的工具。</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>正在加載字體，請稍候...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>該字體已導出到桌面</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1個字體已導出到桌面</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，1 個文件導出失敗</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，%1 個文件導出失敗</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>添加字體</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>啟用字體</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>禁用字體</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除字體</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出字體</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>字體已被禁用</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1正在被使用，無法禁用</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>不可禁用系統字體和使用中的字體</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>不可禁用系統字體</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>部分系統字體不允許被禁用</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>安裝字體</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>正在驗證...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>文件已損壞</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>已安裝</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>未安裝</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>安裝字體</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>暫無字體</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>添加字體</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>字體訊息</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>輸入文本內容進行預覽</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>文件已損壞</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>所有字體</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統字體</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用戶字體</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>已啟動</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中文字體</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>等寬字體</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1是一個字體集，將它刪除可能會刪除屬於它的所有字體</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>刪 除</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1是一個字體集，將它啟用可能會啟用屬於它的所有字體</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1是一個字體集，將它禁用可能會禁用屬於它的所有字體</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>啟 用</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>禁 用</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>應用到所有選定的字體集</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>文件已損壞</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>已安裝相同版本</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>系統字體</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>已安裝%1個字體</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>已安裝%1個字體</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，%1 個文件安裝失敗</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，%1 個文件安裝失敗</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>刪除後該字體將不可用於其他應用程序</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>刪除後這些字體將不可用於其他應用程序</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>無法刪除其他%1個系統字體</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>無法刪除正在使用的字體：%1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>無法刪除其他%1個系統字體和正在使用的字體：%2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>您確定要刪除這%1個字體嗎？</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>刪 除</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>正在刪除字體，請稍候...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>字體驗證</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>無可用安裝字體</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>退 出</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>繼 續</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>樣式</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>全名</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS名稱</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>商標</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>字體管理器</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>字體管理器是一款幫助用戶安裝和管理字體的工具。</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>正在加載字體，請稍候...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>該字體已導出到桌面</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1個字體已導出到桌面</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，1 個文件導出失敗</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>目標磁盤空間不足，%1 個文件導出失敗</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>添加字體</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>啟用字體</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>禁用字體</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除字體</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>訊息</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出字體</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>字體已被禁用</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1正在被使用，無法禁用</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>不可禁用系統字體和使用中的字體</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>不可禁用系統字體</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>安裝字體</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>正在驗證...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>文件已損壞</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>已安裝</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>未安裝</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>安裝字體</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>暫無字體</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>添加字體</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>字體訊息</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>輸入文本內容進行預覽</translation>
    </message>
</context>
</TS>
